## 0.3.1.2 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.3.1.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.3.1 (2022-06-25)

ujson, pyfarmhash, toposort: check for missing definitions (#8153)

Co-authored-by: hauntsaninja <>

## 0.3.0 (2022-06-14)

[stubsabot] Bump pyfarmhash to 0.3.* (#8079)

Co-authored-by: hauntsaninja <>

## 0.2.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

